<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://siamcomm.com
 * @since             1.0.0
 * @package           Instashare
 *
 * @wordpress-plugin
 * Plugin Name:       InstaShare
 * Plugin URI:        https://github.com/siamcomm/instashare
 * Description:       This plugin adds Social Sharing buttons to the bottom of content in pages and posts, so your visitors can share your website's content.
 * Version:           1.0.0
 * Author:            Eric B
 * Author URI:        https://siamcomm.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       instashare
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-instashare-activator.php
 */
function activate_instashare() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-instashare-activator.php';
	Instashare_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-instashare-deactivator.php
 */
function deactivate_instashare() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-instashare-deactivator.php';
	Instashare_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_instashare' );
register_deactivation_hook( __FILE__, 'deactivate_instashare' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-instashare.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_instashare() {

	$plugin = new Instashare();
	$plugin->run();

}
run_instashare();
